#!/usr/bin/python
# -*- coding:utf-8 -*-

"""An abstract class of scoreboard classes.
"""

from dom import *
import scorecard
import fifa_2005

def newInstance():
    """This method must be inplemented in subclasses which instanciate
    an object."""
    return NetherlandWY_fifa_2005()


class NetherlandWY_fifa_2005( fifa_2005.FIFA_2005 ):
    def __init__( self ):
        fifa_2005.FIFA_2005.__init__( self )
        return

    """Overridable methods"""
    def getSportsCategory( self ):
        return "soccer"

    def getCountry( self ):
        return "World"

    def getName( self ):
        return "FIFA WY2005 (fifa.com)"

    def getVersion( self ):
        return "1.0"

    def getEncoding( self ):
        return 'iso-8859-1'

    def getLanguage( self ):
        return "en"

    def decode( self, content ):
        return content

    def getURL( self ):
        return "http://www.fifa.com/en/comp/WYC/WYCScoreCard/0,4380,WYC-2005-10000,00.html"

    def __resolve_table( self, row ):
        title = row.get_text()
        data = []
        while row != None:
            info = row.get_text( '--*--' ).split( '--*--' )
            if len( info ) >= 3:
                date = info[ 0 ]
                group = info[ 1 ]
                group = re.sub( "Group[^A-Z]*", '', group, re.I )
                place = info[ 2 ]
                row = row.next_sibling()
                result = row.get_text( '--*--' ).split( '--*--' )
                if len( result ) >= 6:
                    team1 = result[ 1 ]
                    icon1 = self.getIcon( fifa_2005.FIFA_2005.get_nation_code( team1 ) )
                    #icon1 = '<img class="teamlogo" src="%s"/>' % self.getIcon( fifa_2005.FIFA_2005.get_nation_code( team1 ) )
                    score = result[ 2 ]
                    score = re.sub( ':', '-', score )
                    team2 = result[ 3 ]
                    icon2 = self.getIcon( fifa_2005.FIFA_2005.get_nation_code( team2 ) )
                    #icon2 = '<img class="teamlogo" src="%s"/>' % self.getIcon( fifa_2005.FIFA_2005.get_nation_code( team2 ) )
                    start = result[ 5 ]
                    data.append( ( group, icon1, team1, score, team2, icon2, place, date + ' ' + start ) )
                    pass
                pass
            try:
                row = row.next_sibling( 'tr' )
            except:
                break
            pass
        table = {'title':title, 'data':data }
        if len( data ) > 0:
            return table
        return None
        
    def interpreteDocument( self, document ):
        import re, sys
        #print document
        self.headerclasses = ( 'group', 'logo', 'team', 'score', 'team', 'logo', 'place', 'state' )
        elem_upcoming = document.get_element_at_path( "/html/table/tr" )
        table = self.__resolve_table( elem_upcoming )
        if table: self.tables.append( table )
        elem_recent = document.get_element_at_path( "/html/table,2/tr" )
        table = self.__resolve_table( elem_recent )
        if table: self.tables.append( table )
        self.tables.reverse()
        return


    def getIgnorableTags( self ):
        return ( 'script', 'span' )

    def getStartKeyword( self ):
        return ".livescore-font"

    def getEndKeyword( self ):
        return "Flash Player"

    def html_css_plugin( self ):
        return """<style type=\"text/css\">
        .teamlogo {width:32;}
        .group { width:15px; }
        .place { width:80px; font-size:9px; font-weight: normal; }
        </style>
        """

    pass


if __name__ == "__main__":
    """unit test"""
    filename_sample = None 
    import sys
    from loader import *

    if len( sys.argv ) > 1: filename_sample = sys.argv[ 1 ]
    
    obj = newInstance()

    if obj != None and obj.isAvailable():
        url = obj.getURL()
        if filename_sample:
            data = ""
            for line in open( filename_sample ).readlines():
                data += line
                pass
            pass
        else:
            data = loadHTML( url )
            pass
        kw_start = obj.getStartKeyword()
        kw_end   = obj.getEndKeyword()
        parser = DOMConverter()
        for tag in obj.getIgnorableTags():
            parser.add_ignoring_tag( tag )
            pass
        if kw_start == None or kw_end == None:
            for line in data.split( "\n" ):
                parser.feed( obj.decode( line ) )
                pass
            pass
        else:
            flag_inside = False
            parser.feed( '<html>' )
            for line in re.split( "\n", data ):
                line = obj.decode( line.strip() )
                if flag_inside:
                    if line.count( kw_end ): flag_inside = False
                    else: parser.feed( line )
                elif line.count( kw_start ):
                    flag_inside = True
                    pass
                pass
            parser.feed( '</html>' )
            pass
        document = parser.get_document()
        obj.interpreteDocument( document )
        print obj.toHTML()
        pass
    pass
